/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { defineComponent as r, ref as l, createVNode as i, h as n } from "vue";
import { validatePackage as u, setRef as d, getTabIndex as p, classNames as o, kendoThemeMaps as h, templateRendering as c, getListeners as m, getTemplate as f } from "@progress/kendo-vue-common";
import { selectionReducer as $ } from "./selection-reducer.mjs";
import { focusReducer as v } from "./focus-reducer.mjs";
import { dataReducer as D } from "./data-reducer.mjs";
import { Chip as g } from "./Chip.mjs";
import { packageMetadata as y } from "../package-metadata.mjs";
const V = /* @__PURE__ */ r({
  name: "KendoVueChipList",
  inheritAttrs: !1,
  props: {
    id: String,
    tabIndex: Number,
    dataItems: Array,
    defaultDataItems: {
      type: Array,
      default: function() {
        return [];
      }
    },
    value: [Object, Array, String, Number],
    defaultValue: {
      type: [Object, Array, String, Number],
      default: function() {
        return null;
      }
    },
    size: {
      type: String,
      default: "medium"
    },
    rounded: {
      type: String,
      default: "medium"
    },
    fillMode: {
      type: String,
      default: "solid",
      validator: function(t) {
        return [null, "flat", "outline", "solid"].includes(t);
      }
    },
    selection: {
      type: String,
      default: function() {
        return "none";
      }
    },
    textField: {
      type: String,
      default: function() {
        return "text";
      }
    },
    valueField: {
      type: String,
      default: function() {
        return "value";
      }
    },
    avatarField: {
      type: String,
      default: function() {
        return "avatar";
      }
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    dir: {
      type: String,
      default: function() {
        return "ltr";
      }
    },
    chip: [String, Function, Object],
    ariaLabelledBy: String,
    ariaDescribedBy: String
  },
  provide() {
    return {
      kendoSelection: this.currentValue,
      kendoFocused: this.currentFocused,
      kendoDataItems: this.computedDataItems,
      handleDispatchDataItems: this.handleDispatchDataItems,
      handleDispatchSelection: this.handleDispatchSelection,
      handleDispatchFocus: this.handleDispatchFocus
    };
  },
  created() {
    u(y), this.currentDataItems = this.$props.dataItems || this.$props.defaultDataItems, this.currentValue.value = this.$props.value || this.$props.defaultValue;
  },
  data() {
    return {
      currentDataItems: [],
      currentDir: "ltr",
      isRtl: !1,
      currentFocused: {
        value: !1
      },
      currentValue: {
        value: null
      }
    };
  },
  mounted() {
    this.chipList = this.chipListRef, this.currentDir = this.$props.dir !== void 0 ? this.$props.dir : this.$el && getComputedStyle(this.$el).direction === "rtl" || !1, this.isRtl = this.currentDir === "rtl";
  },
  computed: {
    computedDataItems() {
      return this.$props.dataItems || this.currentDataItems;
    },
    computedValue() {
      return this.$props.value || this.currentValue.value;
    },
    items() {
      return this.computedDataItems.reduce(this.itemsReducer, []);
    }
  },
  methods: {
    handleDispatchSelection(t) {
      const e = $(this.computedValue, {
        ...t,
        selection: this.$props.selection,
        state: this.computedValue
      });
      this.handleChange(e, t.event), this.currentValue.value = e;
    },
    handleDispatchFocus(t) {
      const e = v(t.payload, {
        ...t,
        items: this.items
      });
      this.currentFocused.value = e;
    },
    handleDispatchDataItems(t) {
      const e = D(this.computedDataItems, {
        ...t,
        state: this.computedDataItems,
        valueField: this.$props.valueField
      });
      this.handleDataChange(e, t.event), this.currentDataItems = e;
    },
    handleChange(t, e) {
      this.$el && this.$emit("change", {
        value: t,
        target: this.$el,
        event: e
      });
    },
    handleDataChange(t, e) {
      this.$el && this.$emit("datachange", {
        value: t,
        target: this.$el,
        event: e
      });
    },
    itemsReducer(t, e) {
      return t.push(e[this.$props.valueField || this.$props.valueField]), t;
    }
  },
  setup() {
    return {
      chipListRef: l(null)
    };
  },
  render() {
    const {
      size: t
    } = this.$props;
    return i("div", {
      ref: d(this, "chipList"),
      role: "listbox",
      id: this.$props.id,
      dir: this.currentDir,
      style: this.$attrs.style,
      tabindex: p(this.$props.tabIndex, this.$props.disabled, void 0),
      class: o("k-chip-list", {
        [`k-chip-list-${h.sizeMap[t] || t}`]: t,
        "k-rtl": this.currentDir === "rtl",
        "k-selection-single": this.$props.selection === "single",
        "k-selection-multiple": this.$props.selection === "multiple",
        "k-disabled": this.$props.disabled
      }),
      "aria-labelledby": this.$props.ariaLabelledBy,
      "aria-describedby": this.$props.ariaDescribedBy,
      "aria-orientation": "horizontal",
      "aria-multiselectable": this.$props.selection === "multiple" ? !0 : void 0
    }, [this.computedDataItems.map(function(e) {
      const s = c.call(this, this.$props.chip, m.call(this)), a = i(g, {
        role: "option",
        dataItem: e,
        key: e[this.$props.valueField],
        text: e[this.$props.textField],
        value: e[this.$props.valueField],
        avatar: e[this.$props.avatarField],
        size: this.$props.size,
        rounded: this.$props.rounded,
        fillMode: this.$props.fillMode
      }, null);
      return f.call(this, {
        h: n,
        template: s,
        defaultRendering: a,
        additionalProps: {
          dataItem: e,
          key: e[this.$props.valueField],
          text: e[this.$props.textField],
          value: e[this.$props.valueField],
          size: this.$props.size
        }
      });
    }, this)]);
  }
});
export {
  V as ChipList
};
